/* HostsSwitcherV2 --------------------------------------------------
 * GuiProcessor.java
 * -------------------------------------
 * CF
 *     2005/10/02	VK쐬
 * -----------------------------------------------------------------*/
package info.createwanwan.hostsswitcher;

import info.createwanwan.hostsswitcher.common.HostsFileHandler;
import info.createwanwan.hostsswitcher.common.PropertiesHandler;

import java.io.IOException;

import javax.swing.JFileChooser;
import javax.swing.JOptionPane;

public class GuiProcessor implements Processor{
	private PropertiesHandler propHandler;
	private HostsFileHandler hostsHandler;
	private String hostsFilePath;
	private JFileChooser fileChooser;
	
	public void process(String propPath) {
		// Open Properties File
		hostsFilePath = findHostsFilePath(propPath);
		if ((hostsFilePath == null) ||  (hostsFilePath.equals(""))){
			showHostsErrorMessage("Not Found");
			System.exit(9);
		}
		try {
			hostsHandler = new HostsFileHandler(hostsFilePath);
			HostsSwitcherGuiPanel mainPanel = new HostsSwitcherGuiPanel(hostsHandler);
			mainPanel.setVisible(true);
		} catch (Exception e) {
			showHostsErrorMessage(e.getMessage());
			System.exit(9);
		}
	}
	private void showHostsErrorMessage(String msg){
		JOptionPane.showMessageDialog(null, "Please select valid Hosts file. [" + msg + "]", "Error", JOptionPane.OK_OPTION);
	}
	
	private String findHostsFilePath(String path){
		String hostsPath = "";
		try {
			propHandler = new PropertiesHandler(path);
			hostsPath = propHandler.getHostsPath();
			//debug("<1>" + hostsPath);
			if ((hostsPath == null) || (hostsPath.equals(""))){
				//debug("<2-a>" + hostsPath);
				hostsPath = findHostsByFileChooser();
				//debug("<2-b>" + hostsPath);
			}
		} catch (IOException e) {
			hostsPath = findHostsByFileChooser();
		}
		return hostsPath;
	}
	
	private String findHostsByFileChooser(){
		String hostsPath = "";
		fileChooser = new JFileChooser();
		// Set Window Title
		fileChooser.setDialogTitle("Open The Hosts File");
		// Only Choose Simple file
		fileChooser.setFileSelectionMode(JFileChooser.FILES_ONLY);
		int result = fileChooser.showOpenDialog(null);
		if (result == JFileChooser.APPROVE_OPTION) {
			hostsPath = fileChooser.getSelectedFile().getAbsolutePath();
			int selection = JOptionPane.showConfirmDialog(null, "Save the Hosts Path?", "", JOptionPane.YES_NO_OPTION);
			if (selection == JOptionPane.YES_OPTION) {
				PropertiesHandler propHandler = new PropertiesHandler();
				propHandler.setHostsPath(hostsPath);
				try {
					propHandler.saveNewProperties();
				} catch (IOException e1) {
					JOptionPane.showMessageDialog(null, "Writing the properties file is fail.", "Error", JOptionPane.OK_OPTION);
					System.exit(19);
				}
			}
		}
		return hostsPath;
	}
	
	private void debug(String s){
		System.out.println(this.getClass()	 + " DEBUG MSG : " + s);
	}
}
